synthetic package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   synthetic.fetch_data
   synthetic.generator
   synthetic.predictor

Module contents
---------------

.. automodule:: synthetic
   :members:
   :undoc-members:
   :show-inheritance:
